"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _reactNativeWebview = _interopRequireDefault(require("react-native-webview"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
const MapHtml = require('./JibestreamMap.html');
const handleLogMessage = (level, message) => {
  switch (level) {
    case 'LOG':
      console.log('MESSAGE FROM WEBVIEW:', message);
      break;
    case 'DEBUG':
      console.debug('MESSAGE FROM WEBVIEW:', message);
      break;
    case 'INFO':
      console.info('MESSAGE FROM WEBVIEW:', message);
      break;
    case 'WARN':
      console.warn('MESSAGE FROM WEBVIEW:', message);
      break;
    case 'ERROR':
      console.error('MESSAGE FROM WEBVIEW:', message);
      break;
  }
};
const MapView = (props, parentRef) => {
  const webviewRef = (0, _react.useRef)(null);
  (0, _react.useEffect)(() => {}, []);
  const onWayfindToWaypoint = waypointId => {
    sendCommandToMap('WAYFIND_TO_WAYPOINT', waypointId);
  };
  const onWayfindBetweenWaypoints = (originId, destinationId) => {
    sendCommandToMap('WAYFIND_BETWEEN_WAYPOINTS', {
      originId,
      destinationId
    });
  };
  const drawNavigationPath = function (pathId) {
    let shouldFocus = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
    let style = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {
      stroke: '#ffc956',
      strokeWidth: 3
    };
    sendCommandToMap('DRAW_NAVIGATION_PATH', {
      pathId,
      style,
      shouldFocus
    });
  };
  const onStyleShape = function (unitId) {
    let style = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
      fill: '#ABABAB'
    };
    sendCommandToMap('STYLE_SHAPE', {
      id: unitId,
      style
    });
  };
  const onStyleUnitsForDestination = function (destination) {
    let style = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
      fill: '#ABABAB'
    };
    sendCommandToMap('STYLE_SHAPE', {
      destination,
      style
    });
  };
  const onSetMapVenue = (credentials, compass, floorSelector, zoomButtons, search) => {
    sendCommandToMap('SET_MAP_VENUE', {
      credentials,
      compass,
      floorSelector,
      zoomButtons,
      search
    });
  };
  (0, _react.useImperativeHandle)(parentRef, () => {
    const listeners = {
      setMapVenue: _ref => {
        let {
          credentials,
          compass,
          floorSelector,
          zoomButtons,
          search
        } = _ref;
        onSetMapVenue(credentials, compass, floorSelector, zoomButtons, search);
      },
      centerMapOnPoint: point => {
        sendCommandToMap('CENTER_MAP_ON_POINT', point);
      },
      setFollowBlueDot: function (enabled) {
        let rotate = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
        let interval = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 500;
        sendCommandToMap('SET_FOLLOW_BLUE_DOT', {
          enabled,
          rotate,
          interval
        });
      },
      setUserPosition: (lat, long, heading) => {
        sendCommandToMap('UPDATE_USER_LOCATION', {
          lat,
          long,
          heading
        });
      },
      clearWayfindingPath: () => {
        sendCommandToMap('CLEAR_WAYFINDING_PATH', '');
      },
      wayfindToWaypoint: waypointId => {
        onWayfindToWaypoint(waypointId);
      },
      wayfindBetweenWaypoints: (originId, destinationId) => {
        onWayfindBetweenWaypoints(originId, destinationId);
      },
      drawNavigationPath: (pathId, shouldFocus, style) => {
        drawNavigationPath(pathId, shouldFocus, style);
      },
      styleUnitsForDestination: (destination, style) => {
        onStyleUnitsForDestination(destination, style);
      },
      styleShape: (unitId, style) => {
        onStyleShape(unitId, style);
      }
    };
    return listeners;
  });
  function onMessage(message) {
    var _props$onMapMessage$o, _props$onMapMessage, _props$onMapMessage$o2, _props$onMapMessage2, _props$onMapMessage$o3, _props$onMapMessage3, _props$onMapMessage$o4, _props$onMapMessage4, _props$onMapMessage$o5, _props$onMapMessage5;
    const obj = JSON.parse(message.nativeEvent.data);
    const command = obj.command;
    const data = obj.data;
    // props.onMapMessage(command, data);
    switch (command) {
      case 'DESTINATION_SELECTED':
        (_props$onMapMessage$o = (_props$onMapMessage = props.onMapMessage).onDestinationSelected) === null || _props$onMapMessage$o === void 0 ? void 0 : _props$onMapMessage$o.call(_props$onMapMessage, data);
        break;
      case 'NAVIGATION_PATH_GENERATED':
        const obj = data;
        (_props$onMapMessage$o2 = (_props$onMapMessage2 = props.onMapMessage).onNavigationPathGenerated) === null || _props$onMapMessage$o2 === void 0 ? void 0 : _props$onMapMessage$o2.call(_props$onMapMessage2, obj.pathId, obj.instructions, obj.start, obj.end, obj.path);
        break;
      case 'USER_POSITION_UPDATED':
        (_props$onMapMessage$o3 = (_props$onMapMessage3 = props.onMapMessage).onUserPositionUpdated) === null || _props$onMapMessage$o3 === void 0 ? void 0 : _props$onMapMessage$o3.call(_props$onMapMessage3, data);
        break;
      case 'WINDOW_LOADED':
        (_props$onMapMessage$o4 = (_props$onMapMessage4 = props.onMapMessage).onWindowLoaded) === null || _props$onMapMessage$o4 === void 0 ? void 0 : _props$onMapMessage$o4.call(_props$onMapMessage4);
        break;
      case 'GENERATED_SEARCH_DESTINATIONS':
        (_props$onMapMessage$o5 = (_props$onMapMessage5 = props.onMapMessage).onSearchDestinationsGenerated) === null || _props$onMapMessage$o5 === void 0 ? void 0 : _props$onMapMessage$o5.call(_props$onMapMessage5, data);
        break;
      case 'CONSOLE_LOG':
        console.log("Received COnsole Log Message");
        const logObj = data;
        handleLogMessage(logObj.level, logObj.message);
        break;
      default:
        console.log('Unhandled command from map:', command, data);
        break;
    }
  }
  function sendCommandToMap(command, data) {
    const clientResponseCode = `
    window.postMessage(${JSON.stringify({
      command,
      data
    })}, "*");
    true;
  `;
    if (webviewRef.current)
      // @ts-ignore
      webviewRef.current.injectJavaScript(clientResponseCode);
  }
  return /*#__PURE__*/_react.default.createElement(_reactNative.SafeAreaView, {
    style: {
      flex: 1,
      width: '100%',
      height: '100%'
    }
  }, /*#__PURE__*/_react.default.createElement(_reactNativeWebview.default
  // injectedJavaScript={debugging}
  , {
    ref: webviewRef,
    scalesPageToFit: false,
    mixedContentMode: "compatibility",
    onMessage: onMessage,
    source: MapHtml
  }));
};
var _default = /*#__PURE__*/(0, _react.forwardRef)(MapView);
exports.default = _default;
//# sourceMappingURL=MapView.js.map