import React, { forwardRef, useEffect } from 'react';
import { useImperativeHandle, useRef } from 'react';
import { requireNativeComponent, UIManager, findNodeHandle, DeviceEventEmitter, NativeEventEmitter, NativeModules, Platform } from 'react-native';
const OdpViewManagerCommands = {
  start: 1,
  upload_logs: 2
};
const startOdp = (viewId, key, host) => UIManager.dispatchViewManagerCommand(viewId, OdpViewManagerCommands.start.toString(), [key, host]);
const uploadLogs = viewId => UIManager.dispatchViewManagerCommand(viewId, OdpViewManagerCommands.upload_logs.toString(), []);

// const LINKING_ERROR =
//   `The package 'react-native-library' doesn't seem to be linked. Make sure: \n\n` +
//   Platform.select({ ios: "- You have run 'pod install'\n", default: '' }) +
//   '- You rebuilt the app after installing the package\n' +
//   '- You are not using Expo Go\n';

const OdpViewManager = requireNativeComponent('OdpViewManager');

// const OdpComponent =
//   UIManager.getViewManagerConfig('OdpViewManager') != null
//     ? requireNativeComponent('OdpViewManager')
//     : () => {
//         throw new Error(LINKING_ERROR);
//       };

const {
  CTPEventEmitter,
  OdpViewManagerManager
} = NativeModules;
const OdpModule = (props, parentRef) => {
  const nodeRef = useRef(null);
  useEffect(() => {
    var _eventEmitter, _eventEmitter2, _eventEmitter3, _eventEmitter4;
    console.log('Initializing Event Emitter');
    let eventEmitter = null;
    if (Platform.OS == 'android') {
      eventEmitter = DeviceEventEmitter;
    } else if (Platform.OS == 'ios') {
      eventEmitter = new NativeEventEmitter(CTPEventEmitter);
    }
    (_eventEmitter = eventEmitter) === null || _eventEmitter === void 0 ? void 0 : _eventEmitter.addListener('onReady', event => {
      var _props$onOdpEvent$onR, _props$onOdpEvent;
      console.log('ODP onReady');
      (_props$onOdpEvent$onR = (_props$onOdpEvent = props.onOdpEvent).onReady) === null || _props$onOdpEvent$onR === void 0 ? void 0 : _props$onOdpEvent$onR.call(_props$onOdpEvent, event);
    });
    (_eventEmitter2 = eventEmitter) === null || _eventEmitter2 === void 0 ? void 0 : _eventEmitter2.addListener('onKeyValidation', event => {
      var _props$onOdpEvent$onK, _props$onOdpEvent2;
      console.log('ODP onKeyValidation');
      (_props$onOdpEvent$onK = (_props$onOdpEvent2 = props.onOdpEvent).onKeyValidation) === null || _props$onOdpEvent$onK === void 0 ? void 0 : _props$onOdpEvent$onK.call(_props$onOdpEvent2, event);
    });
    (_eventEmitter3 = eventEmitter) === null || _eventEmitter3 === void 0 ? void 0 : _eventEmitter3.addListener('onNavigationUpdate', event => {
      var _props$onOdpEvent$onN, _props$onOdpEvent3;
      (_props$onOdpEvent$onN = (_props$onOdpEvent3 = props.onOdpEvent).onNavigationUpdate) === null || _props$onOdpEvent$onN === void 0 ? void 0 : _props$onOdpEvent$onN.call(_props$onOdpEvent3, event);
    });
    (_eventEmitter4 = eventEmitter) === null || _eventEmitter4 === void 0 ? void 0 : _eventEmitter4.addListener('onFacilityUpdate', event => {
      var _props$onOdpEvent$onF, _props$onOdpEvent4;
      console.log('ODP onFacilityUpdate');
      (_props$onOdpEvent$onF = (_props$onOdpEvent4 = props.onOdpEvent).onFacilityUpdate) === null || _props$onOdpEvent$onF === void 0 ? void 0 : _props$onOdpEvent$onF.call(_props$onOdpEvent4, event);
    });
    return () => {
      var _eventEmitter5, _eventEmitter6, _eventEmitter7, _eventEmitter8;
      console.log('Removing Event Emitters');
      (_eventEmitter5 = eventEmitter) === null || _eventEmitter5 === void 0 ? void 0 : _eventEmitter5.removeAllListeners('onReady');
      (_eventEmitter6 = eventEmitter) === null || _eventEmitter6 === void 0 ? void 0 : _eventEmitter6.removeAllListeners('onKeyValidation');
      (_eventEmitter7 = eventEmitter) === null || _eventEmitter7 === void 0 ? void 0 : _eventEmitter7.removeAllListeners('onNavigationUpdate');
      (_eventEmitter8 = eventEmitter) === null || _eventEmitter8 === void 0 ? void 0 : _eventEmitter8.removeAllListeners('onFacilityUpdate');
    };
  }, []);
  useImperativeHandle(parentRef, () => {
    const nodeHandle = findNodeHandle(nodeRef.current);
    const listeners = {
      startOdp: (key, host) => {
        if (Platform.OS == 'ios') {
          // OdpComponent.start(key, host);
          UIManager.getViewManagerConfig('OdpViewManager').Commands.start;
          OdpViewManagerManager.start(key, host);
        } else if (Platform.OS == 'android') {
          startOdp(nodeHandle, key, host);
        }
      },
      uploadLogs: () => {
        if (Platform.OS == 'android') {
          uploadLogs(nodeHandle);
        }
      }
    };
    return listeners;
  });
  return /*#__PURE__*/React.createElement(OdpViewManager, {
    ref: nodeRef
  });
};
export default /*#__PURE__*/forwardRef(OdpModule);
//# sourceMappingURL=OdpViewModule.js.map